summaryrefslogtreecommitdiffstats
path: root/umbrello/umbrello/codeimport/kdevcppparser/urlutil.h
diff options
context:
space:
mode:
Diffstat (limited to 'umbrello/umbrello/codeimport/kdevcppparser/urlutil.h')
-rw-r--r--umbrello/umbrello/codeimport/kdevcppparser/urlutil.h44
1 files changed, 22 insertions, 22 deletions
diff --git a/umbrello/umbrello/codeimport/kdevcppparser/urlutil.h b/umbrello/umbrello/codeimport/kdevcppparser/urlutil.h
index 590069dc..75486983 100644
--- a/umbrello/umbrello/codeimport/kdevcppparser/urlutil.h
+++ b/umbrello/umbrello/codeimport/kdevcppparser/urlutil.h
@@ -21,8 +21,8 @@
#ifndef _URLUTIL_H_
#define _URLUTIL_H_
-#include <qstring.h>
-#include <qvaluelist.h>
+#include <tqstring.h>
+#include <tqvaluelist.h>
#include <kurl.h>
namespace URLUtil
@@ -32,19 +32,19 @@ namespace URLUtil
/**
* Returns the filename part of a pathname (i.e. everything past the last slash)
*/
- QString filename(const QString & pathName);
+ TQString filename(const TQString & pathName);
/**
* Returns the directory part of a path (i.e. everything up to but not including the last slash)
*/
- QString directory(const QString & pathName);
+ TQString directory(const TQString & pathName);
/**
* Returns the relative path between a parent and child URL, or blank if the specified child is not a child of parent
*/
- QString relativePath(const KURL & parent, const KURL & child, uint slashPolicy = SLASH_PREFIX);
+ TQString relativePath(const KURL & parent, const KURL & child, uint slashPolicy = SLASH_PREFIX);
/**
* Returns the relative path between a parent and child URL, or blank if the specified child is not a child of parent
*/
- QString relativePath(const QString & parent, const QString & child, uint slashPolicy = SLASH_PREFIX);
+ TQString relativePath(const TQString & parent, const TQString & child, uint slashPolicy = SLASH_PREFIX);
/**
* Returns the relative path between a directory and file. Should never return empty path.
* Example:
@@ -52,11 +52,11 @@ namespace URLUtil
* fileUrl: /home/test/lib/mylib.cpp
* returns: ../lib/mylib.cpp
*/
- QString relativePathToFile( const QString & dirUrl, const QString & fileUrl );
+ TQString relativePathToFile( const TQString & dirUrl, const TQString & fileUrl );
/**
*Returns the path 'up one level' - the opposite of what filename returns
*/
- QString upDir(const QString & path, bool slashSuffix = false);
+ TQString upDir(const TQString & path, bool slashSuffix = false);
/**
* 'Merges' URLs - changes a URL that starts with dest to start with source instead
* Example:
@@ -69,7 +69,7 @@ namespace URLUtil
/**
* Returns the file extension for a filename or path
*/
- QString getExtension(const QString & path);
+ TQString getExtension(const TQString & path);
/**
* Given a base directory url in @p baseDirUrl and the url referring to a date sub-directory or file,
@@ -79,44 +79,44 @@ namespace URLUtil
* KURL baseUrl, dirUrl;
* baseUrl.setPath( "/home/mario/src/kdevelop/" );
* dirUrl.setPath( "/home/mario/src/kdevelop/parts/cvs/" );
* QString relPathName = extractDirPathRelative( baseUrl, url ); // == "parts/cvs/"
* QString absPathName = extractDirPathAbsolute( url ); // == "/home/mario/src/kdevelop/parts/cvs/"
* </code>
* Note that if you pass a file name in @p url (instead of a directory) or the @p baseUrl is not contained
* in @p url then the function will return "" (void string).
*/
- QString extractPathNameRelative(const KURL &baseDirUrl, const KURL &url );
- QString extractPathNameRelative(const QString &basePath, const KURL &url );
- QString extractPathNameRelative(const QString &basePath, const QString &absFilePath );
+ TQString extractPathNameRelative(const KURL &baseDirUrl, const KURL &url );
+ TQString extractPathNameRelative(const TQString &basePath, const KURL &url );
+ TQString extractPathNameRelative(const TQString &basePath, const TQString &absFilePath );
/**
* Will return the absolute path name referred in @p url.
* Look at above for an example.
*/
- QString extractPathNameAbsolute( const KURL &url );
+ TQString extractPathNameAbsolute( const KURL &url );
/**
* Returns a QStringList of relative (to @p baseDir) paths from a list of KURLs in @p urls
*/
- QStringList toRelativePaths( const QString &baseDir, const KURL::List &urls);
+ TQStringList toRelativePaths( const TQString &baseDir, const KURL::List &urls);
/**
* If @p url is a directory will return true, false otherwise.
*/
bool isDirectory( const KURL &url );
- bool isDirectory( const QString &absFilePath );
+ bool isDirectory( const TQString &absFilePath );
/**
* Will dump the list of KURL @p urls on standard output, eventually printing @ aMessage if it
* is not null.
*/
- void dump( const KURL::List &urls, const QString &aMessage = QString::null );
+ void dump( const KURL::List &urls, const TQString &aMessage = TQString::null );
/**
- * Same as QDir::canonicalPath in later versions of QT. Earlier versions of QT
+ * Same as TQDir::canonicalPath in later versions of QT. Earlier versions of QT
* had this broken, so it's reproduced here.
*/
- QString canonicalPath( const QString & path );
+ TQString canonicalPath( const TQString & path );
/**
* Performs environment variable expansion on @p variable.
@@ -125,7 +125,7 @@ namespace URLUtil
* @return the expanded environment variable value. if the variable
* cannot be expanded, @p variable itself is returned.
*/
- QString envExpand ( const QString &variable );
+ TQString envExpand ( const TQString &variable );
}
@@ -79,44 +79,44 @@ namespace URLUtil
* baseUrl.setPath( "/home/mario/src/kdevelop/" );
* dirUrl.setPath( "/home/mario/src/kdevelop/parts/cvs/" );
- * QString relPathName = extractDirPathRelative( baseUrl, url ); // == "parts/cvs/"
- * QString absPathName = extractDirPathAbsolute( url ); // == "/home/mario/src/kdevelop/parts/cvs/"
+ * TQString relPathName = extractDirPathRelative( baseUrl, url ); // == "parts/cvs/"
+ * TQString absPathName = extractDirPathAbsolute( url ); // == "/home/mario/src/kdevelop/parts/cvs/"
* </code>
* Note that if you pass a file name in @p url (instead of a directory) or the @p baseUrl is not contained
@@ -79,44 +79,44 @@ namespace URLUtil
/**
- * Returns a QStringList of relative (to @p baseDir) paths from a list of KURLs in @p urls
+ * Returns a TQStringList of relative (to @p baseDir) paths from a list of KURLs in @p urls
*/